#[repr(C)]pub struct Meta {
pub rent_exempt_reserve: u64,
pub authorized: Authorized,
pub lockup: Lockup,
}Fields
rent_exempt_reserve: u64👎Deprecated since 3.0.1:
Stake account rent must be calculated via the Rent sysvar. This value will cease to be correct once lamports-per-byte is adjusted.
lockup: LockupImplementations
Sourceimpl Meta
impl Meta
pub fn set_lockup( &mut self, lockup: &LockupArgs, signers: &HashSet<Pubkey>, clock: &Clock, ) -> Result<(), InstructionError>
pub fn auto(authorized: &Pubkey) -> Self